/***동시일자리 변수 구성***/ 

/**(part1) 한해년도의 동시 일자리를 횡으로 데이터를 정렬 (pid를 기준으로 reshape)**/

clear
cd "D:\klips\Stata"

use klips22w, replace 

sort pid jobwave

tab jobwave	

keep if jobwave==22 // 22차년도 응답한 일자리만 남김
drop if jobcens==0 // 회고적 자료는 제외
keep if inlist(jobclass,1,3,5,7) // 22차 당시 진행중인 일자리만 추출

/*종사상지위(jobst)*/

gen jobst=4 // 고용주 	
replace jobst = j150 if inrange(j150,1,3) // 임금근로자
replace jobst=6 if  j150 ==5 // 무급가족종사자
replace jobst=5 if  j150 ==4 & (j502 ==2 | j503 ==0) // 자영업자: 종업원수가 0명인 경우

lab var jobst "종사상지위(1:상용직,2:임시직,3:일용직,4:고용주,5:자영업자,6:무급가족종사자)"

tab jobst 

sort pid jobseq
keep pid jobwave jobseq jobnum jobtype jobclass mainjob jobcens jobst
tab jobwave		


/*동시 일자리 개수(mjob)*/

bysort pid: gen count = _n // _n: 동일 pid에 대해 일자리를 order하는 code
tab count

// 동일한 개인에 대해서 각 변수의 값을 옆으로 데이터 변환 (가로 -> 세로 배열) 
reshape wide jobwave jobseq jobcens jobtype jobclass jobnum mainjob jobst, i( pid ) j(count) 

// 변수 count의 최대값 4는 최대 일자리 개수가 4개임을 의미함. 따라서 일자리 갯수 = jobwave1~4의 4개 열에서 missing이 아닌 열 개수의 합
egen mjob=rownonmiss(jobnum1 jobnum2 jobnum3 jobnum4) 

lab var mjob "동시 일자리 개수"

tab mjob

save "D:\klips\Stata\data\exaple1.dta", replace 


/**(part2)일생동안 몇개의 일자리를 가지고 있는가? (pid와 jobseq를 기준으로 reshape)**/

clear
cd "D:\klips\Stata"

drop if jobcens==0 // 회고적 자료는 제외
keep if inlist(jobwave, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22) // 12-22차 당시 진행중인 일자리만 추출

sort pid jobseq 
tab1 jobwave jobseq 
	
/*종사상지위(jobst)*/

gen jobst=4 // 고용주 	
replace jobst = j150 if inrange(j150,1,3) // 임금근로자
replace jobst=6 if  j150 ==5 // 무급가족종사자
replace jobst=5 if  j150 ==4 & (j502 ==2 | j503 ==0) // 자영업자: 종업원수가 0명인 경우

lab var jobst "종사상지위(1:상용직,2:임시직,3:일용직,4:고용주,5:자영업자,6:무급가족종사자)"

tab jobst 

sort pid jobseq jobwave 
keep pid jobwave jobseq jobnum jobtype jobclass mainjob jobcens jobst

// _n: 동일한 pid와 jobseq에 대해 일자리를 order하는 code
bysort pid jobseq: gen count = _n 
tab count

// 동일한 개인에 대해서 각 변수의 값을 옆으로 데이터 변환 (가로 -> 세로 배열) (pid jobseq 기준)
reshape wide jobwave jobcens jobtype jobclass jobnum mainjob jobst  , i( pid jobseq) j(count) 

save "D:\klips\Stata\data\exaple2.dta", replace 

